@@ -16,6 +16,7 @@
 from neutron_lib.api.definitions import portbindings as pb_def
 from neutron_lib import constants as nl_constants
 from neutron_lib import context as neutron_context
+from neutron_lib.db import api as db_api
 from neutron_lib.exceptions import firewall_v2 as f_exc
 from neutron_lib import rpc as n_rpc
 from oslo_config import cfg
@@ -37,6 +38,7 @@ class FirewallAgentCallbacks(object):
         self.firewall_db = firewall_db
 
     @log_helpers.log_method_call
+    @db_api.CONTEXT_WRITER
     def set_firewall_group_status(self, context, fwg_id, status, **kwargs):
         """Agent uses this to set a firewall_group's status."""
         # Sanitize status first
@@ -56,6 +58,7 @@ class FirewallAgentCallbacks(object):
         return updated and to_update != nl_constants.ERROR
 
     @log_helpers.log_method_call
+    @db_api.CONTEXT_WRITER
     def firewall_group_deleted(self, context, fwg_id, **kwargs):
         """Agent uses this to indicate firewall is deleted."""
         try:
@@ -76,6 +79,7 @@ class FirewallAgentCallbacks(object):
             return True
 
     @log_helpers.log_method_call
+    @db_api.CONTEXT_WRITER
     def get_firewall_groups_for_project(self, context, **kwargs):
         """Gets all firewall_groups and rules on a project."""
         fwg_list = []
@@ -97,6 +101,7 @@ class FirewallAgentCallbacks(object):
         return fwg_list
 
     @log_helpers.log_method_call
+    @db_api.CONTEXT_WRITER
     def get_projects_with_firewall_groups(self, context, **kwargs):
         """Get all projects that have firewall_groups."""
         ctx = neutron_context.get_admin_context()
@@ -105,6 +110,7 @@ class FirewallAgentCallbacks(object):
         return fwg_project_list
 
     @log_helpers.log_method_call
+    @db_api.CONTEXT_WRITER
     def get_firewall_group_for_port(self, context, **kwargs):
         """Get firewall_group is associated with a port."""
         ctx = context.elevated()
@@ -191,14 +197,17 @@ class FirewallAgentDriver(driver_api.FirewallDriverDB,
         return self.rpc_connection.consume_in_threads()
 
     def _rpc_update_firewall_group(self, context, fwg_id):
+        fw_ports = self.firewall_db.get_ports_in_firewall_group(
+            context, fwg_id)
+        if not fw_ports:
+            return
         status_update = {"status": nl_constants.PENDING_UPDATE}
         self.update_firewall_group(context, fwg_id, status_update)
         fwg_with_rules = self.firewall_db.make_firewall_group_dict_with_rules(
             context, fwg_id)
         # this is triggered on an update to fwg rule or policy, no
         # change in associated ports.
-        fwg_with_rules['add-port-ids'] = \
-            self.firewall_db.get_ports_in_firewall_group(context, fwg_id)
+        fwg_with_rules['add-port-ids'] = fw_ports
         fwg_with_rules['del-port-ids'] = []
         fwg_with_rules['port_details'] = self._get_fwg_port_details(
             context, fwg_with_rules['add-port-ids'])
@@ -326,9 +335,10 @@ class FirewallAgentDriver(driver_api.FirewallDriverDB,
         )
 
         # last-port drives agent to ack with status to set state to INACTIVE
-        # Set last-port to True if there are no ports in the new group,
-        # but the old group had ports
-        fwg_with_rules['last-port'] = (old_firewall_group['ports'] and
+        # Set last-port to True if there are no ports in the new group and
+        # the old group had the same number of ports that need to be deleted.
+        fwg_with_rules['last-port'] = (len(old_firewall_group['ports']) == len(
+                                       fwg_with_rules['del-port-ids']) and
                                        not(new_firewall_group['ports']))
 
         LOG.debug("update_firewall_group %s: Add Ports: %s, Del Ports: %s",
