@@ -16,13 +16,11 @@
 import netaddr
 
 from neutron_lib import constants as lib_const
+from neutron_lib.plugins.ml2 import ovs_constants as ovs_consts
 from oslo_log import log as logging
 from oslo_utils import netutils
 
 from neutron.agent import firewall
-from neutron.common import constants
-from neutron.plugins.ml2.drivers.openvswitch.agent.common import constants \
-    as ovs_consts
 
 from neutron_fwaas.services.firewall.service_drivers.agents.drivers.linux.l2\
     import driver_base
@@ -541,12 +539,10 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
                 priority=95,
                 in_port=port.ofport,
                 reg_port=port.ofport,
-                dl_type=constants.ETHERTYPE_IPV6,
+                dl_type=lib_const.ETHERTYPE_IPV6,
                 nw_proto=lib_const.PROTO_NUM_IPV6_ICMP,
                 icmp_type=icmp_type,
-                actions='resubmit(,%d)' % (
-                    ovs_consts.ACCEPTED_EGRESS_TRAFFIC_TABLE)
-            )
+                actions='normal')
 
     # NOTE(ivasilevskaya) That's a copy-paste from neutron ovsfw driver
     # which differs in constants (table numbers) and exception classes
@@ -582,8 +578,7 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
             table=fwaas_ovs_consts.FW_ACCEPT_OR_INGRESS_TABLE,
             priority=80,
             reg_port=ovs_port.ofport,
-            actions='resubmit(,%d)' % (
-                ovs_consts.ACCEPTED_EGRESS_TRAFFIC_TABLE)
+            actions='normal',
         )
 
     # NOTE(ivasilevskaya) That's a copy-paste from neutron ovsfw driver
@@ -620,17 +615,16 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
                 in_port=port.ofport,
                 reg_port=port.ofport,
                 dl_src=mac_addr,
-                dl_type=constants.ETHERTYPE_ARP,
+                dl_type=lib_const.ETHERTYPE_ARP,
                 arp_spa=ip_addr,
-                actions='resubmit(,%d)' % (
-                    ovs_consts.ACCEPTED_EGRESS_TRAFFIC_TABLE)
+                actions='normal'
             )
             self._add_flow(
                 table=fwaas_ovs_consts.FW_BASE_EGRESS_TABLE,
                 priority=65,
                 reg_port=port.ofport,
                 ct_state=fwaas_ovs_consts.OF_STATE_NOT_TRACKED,
-                dl_type=constants.ETHERTYPE_IP,
+                dl_type=lib_const.ETHERTYPE_IP,
                 in_port=port.ofport,
                 dl_src=mac_addr,
                 nw_src=ip_addr,
@@ -649,7 +643,7 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
                 reg_port=port.ofport,
                 in_port=port.ofport,
                 ct_state=fwaas_ovs_consts.OF_STATE_NOT_TRACKED,
-                dl_type=constants.ETHERTYPE_IPV6,
+                dl_type=lib_const.ETHERTYPE_IPV6,
                 dl_src=mac_addr,
                 ipv6_src=ip_addr,
                 actions='ct(table={:d},zone=NXM_NX_REG{:d}[0..15])'.format(
@@ -662,8 +656,8 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
         if self.sg_with_ovs:
             accept_or_ingress = ovs_consts.ACCEPT_OR_INGRESS_TABLE
         for dl_type, src_port, dst_port in (
-                (constants.ETHERTYPE_IP, 68, 67),
-                (constants.ETHERTYPE_IPV6, 546, 547)):
+                (lib_const.ETHERTYPE_IP, 68, 67),
+                (lib_const.ETHERTYPE_IPV6, 546, 547)):
             self._add_flow(
                 table=fwaas_ovs_consts.FW_BASE_EGRESS_TABLE,
                 priority=80,
@@ -677,8 +671,8 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
             )
         # Ban dhcp service running on an instance
         for dl_type, src_port, dst_port in (
-                (constants.ETHERTYPE_IP, 67, 68),
-                (constants.ETHERTYPE_IPV6, 547, 546)):
+                (lib_const.ETHERTYPE_IP, 67, 68),
+                (lib_const.ETHERTYPE_IPV6, 547, 546)):
             self._add_flow(
                 table=fwaas_ovs_consts.FW_BASE_EGRESS_TABLE,
                 priority=70,
@@ -697,7 +691,7 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
             priority=70,
             in_port=port.ofport,
             reg_port=port.ofport,
-            dl_type=constants.ETHERTYPE_IPV6,
+            dl_type=lib_const.ETHERTYPE_IPV6,
             nw_proto=lib_const.PROTO_NUM_IPV6_ICMP,
             icmp_type=lib_const.ICMPV6_TYPE_RA,
             actions='resubmit(,%d)' % ovs_consts.DROPPED_TRAFFIC_TABLE
@@ -729,8 +723,8 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
                         fwaas_ovs_consts.REG_PORT,
                         fwaas_ovs_consts.FW_BASE_INGRESS_TABLE),
                 )
-            for ethertype in [constants.ETHERTYPE_IP,
-                    constants.ETHERTYPE_IPV6]:
+            for ethertype in [lib_const.ETHERTYPE_IP,
+                    lib_const.ETHERTYPE_IPV6]:
                 self._add_flow(
                     table=fwaas_ovs_consts.FW_ACCEPT_OR_INGRESS_TABLE,
                     priority=90,
@@ -746,8 +740,7 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
                 table=fwaas_ovs_consts.FW_ACCEPT_OR_INGRESS_TABLE,
                 priority=80,
                 reg_port=port.ofport,
-                actions='resubmit(,%d)' % (
-                    ovs_consts.ACCEPTED_EGRESS_TRAFFIC_TABLE)
+                actions='normal'
             )
 
     # NOTE(ivasilevskaya) That's a copy-paste from neutron ovsfw driver
@@ -780,8 +773,7 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
                 ct_mark=fwaas_ovs_consts.CT_MARK_NORMAL,
                 reg_port=port.ofport,
                 ct_zone=port.vlan_tag,
-                actions='resubmit(,%d)' % (
-                    ovs_consts.ACCEPTED_EGRESS_TRAFFIC_TABLE)
+                actions='normal'
             )
         self._add_flow(
             table=fwaas_ovs_consts.FW_RULES_EGRESS_TABLE,
@@ -790,7 +782,7 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
             ct_state=fwaas_ovs_consts.OF_STATE_NOT_ESTABLISHED,
             actions='resubmit(,%d)' % ovs_consts.DROPPED_TRAFFIC_TABLE
         )
-        for ethertype in [constants.ETHERTYPE_IP, constants.ETHERTYPE_IPV6]:
+        for ethertype in [lib_const.ETHERTYPE_IP, lib_const.ETHERTYPE_IPV6]:
             self._add_flow(
                 table=fwaas_ovs_consts.FW_RULES_EGRESS_TABLE,
                 priority=40,
@@ -812,12 +804,10 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
                 priority=100,
                 reg_port=port.ofport,
                 dl_dst=port.mac,
-                dl_type=constants.ETHERTYPE_IPV6,
+                dl_type=lib_const.ETHERTYPE_IPV6,
                 nw_proto=lib_const.PROTO_NUM_IPV6_ICMP,
                 icmp_type=icmp_type,
-                actions='output:{:d},resubmit(,{:d})'.format(
-                    port.ofport,
-                    ovs_consts.ACCEPTED_INGRESS_TRAFFIC_TABLE),
+                actions='output:{:d}'.format(port.ofport)
             )
 
     # NOTE(ivasilevskaya) That's a copy-paste from neutron ovsfw driver
@@ -827,18 +817,16 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
         self._add_flow(
             table=fwaas_ovs_consts.FW_BASE_INGRESS_TABLE,
             priority=100,
-            dl_type=constants.ETHERTYPE_ARP,
+            dl_type=lib_const.ETHERTYPE_ARP,
             reg_port=port.ofport,
-            actions='output:{:d},resubmit(,{:d})'.format(
-                port.ofport,
-                ovs_consts.ACCEPTED_INGRESS_TRAFFIC_TABLE),
+            actions='output:{:d}'.format(port.ofport)
         )
         self._initialize_ingress_ipv6_icmp(port)
 
         # DHCP offers
         for dl_type, src_port, dst_port in (
-                (constants.ETHERTYPE_IP, 67, 68),
-                (constants.ETHERTYPE_IPV6, 547, 546)):
+                (lib_const.ETHERTYPE_IP, 67, 68),
+                (lib_const.ETHERTYPE_IPV6, 547, 546)):
             self._add_flow(
                 table=fwaas_ovs_consts.FW_BASE_INGRESS_TABLE,
                 priority=95,
@@ -847,13 +835,11 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
                 nw_proto=lib_const.PROTO_NUM_UDP,
                 tp_src=src_port,
                 tp_dst=dst_port,
-                actions='output:{:d},resubmit(,{:d})'.format(
-                    port.ofport,
-                    ovs_consts.ACCEPTED_INGRESS_TRAFFIC_TABLE),
+                actions='output:{:d}'.format(port.ofport)
             )
 
         # Track untracked
-        for dl_type in (constants.ETHERTYPE_IP, constants.ETHERTYPE_IPV6):
+        for dl_type in (lib_const.ETHERTYPE_IP, lib_const.ETHERTYPE_IPV6):
             self._add_flow(
                 table=fwaas_ovs_consts.FW_BASE_INGRESS_TABLE,
                 priority=90,
@@ -902,9 +888,7 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
                 ct_state=state,
                 ct_mark=fwaas_ovs_consts.CT_MARK_NORMAL,
                 ct_zone=port.vlan_tag,
-                actions='output:{:d},resubmit(,{:d})'.format(
-                    port.ofport,
-                    ovs_consts.ACCEPTED_INGRESS_TRAFFIC_TABLE)
+                actions='output:{:d}'.format(port.ofport)
             )
         self._add_flow(
             table=fwaas_ovs_consts.FW_RULES_INGRESS_TABLE,
@@ -913,7 +897,7 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
             ct_state=fwaas_ovs_consts.OF_STATE_NOT_ESTABLISHED,
             actions='resubmit(,%d)' % ovs_consts.DROPPED_TRAFFIC_TABLE
         )
-        for ethertype in [constants.ETHERTYPE_IP, constants.ETHERTYPE_IPV6]:
+        for ethertype in [lib_const.ETHERTYPE_IP, lib_const.ETHERTYPE_IPV6]:
             self._add_flow(
                 table=fwaas_ovs_consts.FW_RULES_INGRESS_TABLE,
                 priority=40,
@@ -972,7 +956,7 @@ class OVSFirewallDriver(driver_base.FirewallL2DriverBase):
                     return
                 ports = range_str.split(':', 1)
                 rule[key_min] = int(ports[0])
-                rule['port_range_max'] = (
+                rule[key_max] = (
                     int(ports[1]) if len(ports) == 2 else int(ports[0]))
 
             add_range('destination_port', 'port_range_min', 'port_range_max')
