@@ -87,7 +87,7 @@ class FWLoggingTestBase(framework.L3AgentTestFramework):
         }
 
     def _initialize_iptables_log(self):
-        self.agent_api = l3_ext_api.L3AgentExtensionAPI({})
+        self.agent_api = l3_ext_api.L3AgentExtensionAPI({}, None)
         log_driver = log.IptablesLoggingDriver(self.agent_api)
         log_driver.initialize(self.resource_rpc)
         log_driver.conf = self.conf
@@ -209,7 +209,8 @@ class FWLoggingTestBase(framework.L3AgentTestFramework):
                 output = linux_utils.execute(exec_cmd,
                                              run_as_root=True,
                                              check_exit_code=True,
-                                             extra_ok_codes=[1])
+                                             extra_ok_codes=[1],
+                                             privsep_exec=True)
                 nflog_rules = [rule for rule in output.splitlines()
                                if 'NFLOG' in rule]
                 return nflog_rules
