@@ -58,8 +58,10 @@ class TestCreateFlowsFromRuleAndPort(base.BaseTestCase):
         self.port = ovsfw.OFPort(
             port_dict, ovs_port, vlan_tag=TESTING_VLAN_TAG)
 
-        self.create_flows_mock = mock.patch.object(
-            rules, 'create_protocol_flows').start()
+        self._mock_create_flows = mock.patch.object(
+            rules, 'create_protocol_flows')
+        self.create_flows_mock = self._mock_create_flows.start()
+        self.addCleanup(self._mock_create_flows.stop)
 
     @property
     def passed_flow_template(self):
