@@ -44,8 +44,10 @@ class TestFWaasV2AgentExtensionBase(base.BaseTestCase):
 
         self.l2 = fwaas_v2.FWaaSV2AgentExtension()
         self.l2.consume_api(mock.Mock())
-        self.driver = mock.patch(
-            'neutron.manager.NeutronManager.load_class_for_provider').start()
+        self._driver_mock = mock.patch(
+            'neutron.manager.NeutronManager.load_class_for_provider')
+        self.driver = self._driver_mock.start()
+        self.addCleanup(self._driver_mock.stop)
         self.l2.initialize(None, 'ovs')
         self.l2.vlan_manager = mock.Mock()
         self.conf = cfg.ConfigOpts()
@@ -618,6 +620,7 @@ class TestAddLocalVlanToPorts(TestFWaasV2AgentExtensionBase):
             'port_id': fake_data.PORT1,
             'id': fake_data.PORT1,
             'network_id': fake_data.NETWORK_ID,
+            'segmentation_id': 101,
             'port_details': {
                 fake_data.PORT1: {
                     'device': 'c12e5c1e-d68e-45bd-a2d3-1f2f32604e41',
@@ -641,7 +644,7 @@ class TestAddLocalVlanToPorts(TestFWaasV2AgentExtensionBase):
         actual = self.l2._add_local_vlan_to_ports([self.port_with_detail])
 
         self.l2.vlan_manager.get.assert_called_once_with(
-            self.port_with_detail['network_id'])
+            self.port_with_detail['network_id'], None)
         self.assertEqual(expect, actual)
 
     def test_port_has_detail_and_id(self):
@@ -651,7 +654,7 @@ class TestAddLocalVlanToPorts(TestFWaasV2AgentExtensionBase):
         actual = self.l2._add_local_vlan_to_ports([self.port_with_detail])
 
         self.l2.vlan_manager.get.assert_called_once_with(
-            self.port_with_detail['network_id'])
+            self.port_with_detail['network_id'], None)
         self.assertEqual(expect, actual)
 
     def test_port_has_no_detail(self):
@@ -661,7 +664,8 @@ class TestAddLocalVlanToPorts(TestFWaasV2AgentExtensionBase):
         actual = self.l2._add_local_vlan_to_ports([self.port_with_detail])
 
         self.l2.vlan_manager.get.assert_called_once_with(
-            self.port_with_detail['network_id'])
+            self.port_with_detail['network_id'],
+            self.port_with_detail['segmentation_id'])
         self.assertEqual(expect, actual)
 
 
